(function (global, factory) {
	typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports, require('@angular/core'), require('@angular/common'), require('jquery'), require('eonasdan-bootstrap-datetimepicker')) :
	typeof define === 'function' && define.amd ? define(['exports', '@angular/core', '@angular/common', 'jquery', 'eonasdan-bootstrap-datetimepicker'], factory) :
	(factory((global['ng-ts-datepicker'] = {}),global.ng.core,global.ng.common,global.jquery));
}(this, (function (exports,core,common,jqueryImport) { 'use strict';

var DATETIME_FORMAT = 'DD/MM/YYYY HH:mm:ss';
var DATE_FORMAT = 'DD/MM/YYYY';
var TIME_FORMAT = 'DD/MM/YYYY';
var jquery = jqueryImport;
var NgTsDatepickerDirective = /** @class */ (function () {
    /**
     * @param {?} el
     */
    function NgTsDatepickerDirective(el) {
        this.el = el;
        /**
         * Emits date selected from datepicker
         */
        this.dateChange = new core.EventEmitter();
        /**
         * Emits empty value once datepicker is clicked
         */
        this.click = new core.EventEmitter();
        this.defaultOptions = {
            allowInputToggle: true,
            format: DATETIME_FORMAT,
            preventInputKeys: true
        };
        this.hasParent = false;
        this.internalOptions = {};
    }
    /**
     * @return {?}
     */
    NgTsDatepickerDirective.prototype.ngOnInit = function () {
        var _this = this;
        this.internalOptions = Object.assign(this.internalOptions, this.defaultOptions, this.options);
        var /** @type {?} */ $parent = jquery(this.el.nativeElement.parentNode);
        this.dpElement = $parent.hasClass('input-group') ? $parent : jquery(this.el.nativeElement);
        if ($parent.hasClass('input-group')) {
            this.dpElement = $parent;
            this.hasParent = true;
        }
        else {
            this.dpElement = jquery(this.el.nativeElement);
        }
        this.appendCalendarIcon();
        var /** @type {?} */ datepickerOptions = Object.assign({}, this.internalOptions);
        delete datepickerOptions.preventInputKeys;
        this.dpElement.datetimepicker(datepickerOptions);
        this.dpElement.data('DateTimePicker').date(this.date);
        this.dpElement.on('dp.change', function (e) {
            if (e.date !== _this.date) {
                _this.date = e.date;
                _this.dateChange.emit(e.date);
            }
        });
        if (this.internalOptions.preventInputKeys) {
            this.dpElement.on('keydown', function (e) {
                e.preventDefault();
            });
        }
        this.dpElement.on('click', function (e) {
            _this.click.emit();
        });
    };
    /**
     * @param {?} changes
     * @return {?}
     */
    NgTsDatepickerDirective.prototype.ngOnChanges = function (changes) {
        if (this.dpElement) {
            var /** @type {?} */ dpe_1 = this.dpElement.data('DateTimePicker');
            if (!!dpe_1) {
                if (changes.options) {
                    jquery.map(changes.options.currentValue, function (value, key) {
                        dpe_1[key](value);
                    });
                }
                if (changes.date && changes.date.currentValue !== undefined) {
                    dpe_1.date(changes.date.currentValue);
                }
                else {
                    dpe_1.date(null);
                }
            }
        }
    };
    /**
     * @return {?}
     */
    NgTsDatepickerDirective.prototype.appendCalendarIcon = function () {
        var /** @type {?} */ groupAddon = document.createElement('span');
        var /** @type {?} */ calendarIcon = document.createElement('span');
        groupAddon.setAttribute('class', 'input-group-addon calendar-addon');
        calendarIcon.setAttribute('class', 'glyphicon glyphicon-calendar');
        groupAddon.appendChild(calendarIcon);
        if (this.hasParent) {
            this.dpElement.append(groupAddon);
            this.dpElement.addClass('datepicker');
        }
        else {
            this.dpElement.parent().addClass('datepicker');
            this.dpElement.after(groupAddon);
        }
    };
    return NgTsDatepickerDirective;
}());
NgTsDatepickerDirective.decorators = [
    { type: core.Directive, args: [{
                // tslint:disable-next-line:directive-selector
                selector: '[ngTsDatepicker]'
            },] },
];
/**
 * @nocollapse
 */
NgTsDatepickerDirective.ctorParameters = function () { return [
    { type: core.ElementRef, },
]; };
NgTsDatepickerDirective.propDecorators = {
    'date': [{ type: core.Input },],
    'options': [{ type: core.Input },],
    'dateChange': [{ type: core.Output },],
    'click': [{ type: core.Output },],
};
var NgTsDatepickerModule = /** @class */ (function () {
    function NgTsDatepickerModule() {
    }
    return NgTsDatepickerModule;
}());
NgTsDatepickerModule.decorators = [
    { type: core.NgModule, args: [{
                imports: [
                    common.CommonModule
                ],
                exports: [
                    NgTsDatepickerDirective
                ],
                declarations: [
                    NgTsDatepickerDirective
                ]
            },] },
];
/**
 * @nocollapse
 */
NgTsDatepickerModule.ctorParameters = function () { return []; };

exports.NgTsDatepickerModule = NgTsDatepickerModule;
exports.DATETIME_FORMAT = DATETIME_FORMAT;
exports.DATE_FORMAT = DATE_FORMAT;
exports.TIME_FORMAT = TIME_FORMAT;
exports.NgTsDatepickerDirective = NgTsDatepickerDirective;

Object.defineProperty(exports, '__esModule', { value: true });

})));
//# sourceMappingURL=ng-ts-datepicker.umd.js.map
