import { Directive, ElementRef, EventEmitter, Input, NgModule, Output } from '@angular/core';
import { CommonModule } from '@angular/common';
import * as jqueryImport from 'jquery';
import 'eonasdan-bootstrap-datetimepicker';

const DATETIME_FORMAT = 'DD/MM/YYYY HH:mm:ss';
const DATE_FORMAT = 'DD/MM/YYYY';
const TIME_FORMAT = 'DD/MM/YYYY';

const jquery = jqueryImport;
class NgTsDatepickerDirective {
    /**
     * @param {?} el
     */
    constructor(el) {
        this.el = el;
        /**
         * Emits date selected from datepicker
         */
        this.dateChange = new EventEmitter();
        /**
         * Emits empty value once datepicker is clicked
         */
        this.click = new EventEmitter();
        this.defaultOptions = {
            allowInputToggle: true,
            format: DATETIME_FORMAT,
            preventInputKeys: true
        };
        this.hasParent = false;
        this.internalOptions = {};
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        this.internalOptions = Object.assign(this.internalOptions, this.defaultOptions, this.options);
        const /** @type {?} */ $parent = jquery(this.el.nativeElement.parentNode);
        this.dpElement = $parent.hasClass('input-group') ? $parent : jquery(this.el.nativeElement);
        if ($parent.hasClass('input-group')) {
            this.dpElement = $parent;
            this.hasParent = true;
        }
        else {
            this.dpElement = jquery(this.el.nativeElement);
        }
        this.appendCalendarIcon();
        const /** @type {?} */ datepickerOptions = Object.assign({}, this.internalOptions);
        delete datepickerOptions.preventInputKeys;
        this.dpElement.datetimepicker(datepickerOptions);
        this.dpElement.data('DateTimePicker').date(this.date);
        this.dpElement.on('dp.change', (e) => {
            if (e.date !== this.date) {
                this.date = e.date;
                this.dateChange.emit(e.date);
            }
        });
        if (this.internalOptions.preventInputKeys) {
            this.dpElement.on('keydown', (e) => {
                e.preventDefault();
            });
        }
        this.dpElement.on('click', (e) => {
            this.click.emit();
        });
    }
    /**
     * @param {?} changes
     * @return {?}
     */
    ngOnChanges(changes) {
        if (this.dpElement) {
            const /** @type {?} */ dpe = this.dpElement.data('DateTimePicker');
            if (!!dpe) {
                if (changes.options) {
                    jquery.map(changes.options.currentValue, (value, key) => {
                        dpe[key](value);
                    });
                }
                if (changes.date && changes.date.currentValue !== undefined) {
                    dpe.date(changes.date.currentValue);
                }
                else {
                    dpe.date(null);
                }
            }
        }
    }
    /**
     * @return {?}
     */
    appendCalendarIcon() {
        const /** @type {?} */ groupAddon = document.createElement('span');
        const /** @type {?} */ calendarIcon = document.createElement('span');
        groupAddon.setAttribute('class', 'input-group-addon calendar-addon');
        calendarIcon.setAttribute('class', 'glyphicon glyphicon-calendar');
        groupAddon.appendChild(calendarIcon);
        if (this.hasParent) {
            this.dpElement.append(groupAddon);
            this.dpElement.addClass('datepicker');
        }
        else {
            this.dpElement.parent().addClass('datepicker');
            this.dpElement.after(groupAddon);
        }
    }
}
NgTsDatepickerDirective.decorators = [
    { type: Directive, args: [{
                // tslint:disable-next-line:directive-selector
                selector: '[ngTsDatepicker]'
            },] },
];
/**
 * @nocollapse
 */
NgTsDatepickerDirective.ctorParameters = () => [
    { type: ElementRef, },
];
NgTsDatepickerDirective.propDecorators = {
    'date': [{ type: Input },],
    'options': [{ type: Input },],
    'dateChange': [{ type: Output },],
    'click': [{ type: Output },],
};

class NgTsDatepickerModule {
}
NgTsDatepickerModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    CommonModule
                ],
                exports: [
                    NgTsDatepickerDirective
                ],
                declarations: [
                    NgTsDatepickerDirective
                ]
            },] },
];
/**
 * @nocollapse
 */
NgTsDatepickerModule.ctorParameters = () => [];

/**
 * Generated bundle index. Do not edit.
 */

export { NgTsDatepickerModule, DATETIME_FORMAT, DATE_FORMAT, TIME_FORMAT, NgTsDatepickerDirective };
//# sourceMappingURL=ng-ts-datepicker.js.map
